@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,5 +8,17 @@
 #
 # Thanks for using Enthought open source!
 
+"""
+
+API for the ``pyface.data_view.exporters`` subpackage.
+
+Exporters
+---------
+
+- :class:`~.ItemExporter`
+- :class:`~.RowExporter`
+
+"""
+
 from .item_exporter import ItemExporter
 from .row_exporter import RowExporter
