@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -78,7 +78,8 @@ from .schema import (
     SMenuBar,
     SToolBar,
 )
-from .schema_addition import SchemaAddition
+# deprecated: will be removed in a future Pyface release
+from pyface.action.schema.schema_addition import SchemaAddition
 from .task_action import (
     CentralPaneAction,
     DockPaneAction,
